@@ -1,11 +1,12 @@
 package Perinci::CmdLine::Any;
 
-our $DATE = '2016-07-20'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2017-07-22'; # DATE
+our $VERSION = '0.14'; # VERSION
 
-use 5.010001;
-use strict;
-use warnings;
+# IFUNBUILT
+# use strict;
+# use warnings;
+# END IFUNBUILT
 
 my %Opts = (
     -prefer_lite => 1,
@@ -70,7 +71,7 @@ Perinci::CmdLine::Any - Choose Perinci::CmdLine implementation (::Lite or ::Clas
 
 =head1 VERSION
 
-This document describes version 0.13 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2016-07-20.
+This document describes version 0.14 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2017-07-22.
 
 =head1 SYNOPSIS
 
@@ -141,7 +142,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
